#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class Employee:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'ssn': 'str',
            'last_name': 'str',
            'middle_name': 'str',
            'emergency_contact_number': 'str',
            'date_terminated': 'str',
            'dob': 'str',
            'alcohol_commission_number': 'str',
            'alcohol_commission_expiration_date': 'str',
            'first_name': 'str',
            'is_manager': 'bool',
            'health_cert_number': 'str',
            'mobile_phone': 'str',
            'date_hired': 'str',
            'home_phone': 'str',
            'country_of_nationality': 'str',
            'emergency_contact_name': 'str',
            'health_cert_expiration_date': 'str',
            'date_last_review': 'str',
            'user_name': 'str',
            'email': 'str',
            'employee_id': 'int'

        }


        #Social Security Number
        self.ssn = None # str
        #Last Name
        self.last_name = None # str
        #Middle Name
        self.middle_name = None # str
        #Emergency Contact Number
        self.emergency_contact_number = None # str
        #Date of Termination
        self.date_terminated = None # str
        #Date of Birth
        self.dob = None # str
        #Alcohol Commission Certification Number
        self.alcohol_commission_number = None # str
        #Alcohol Commission Certification Expiration Date
        self.alcohol_commission_expiration_date = None # str
        #First Name
        self.first_name = None # str
        #Manager Flag
        self.is_manager = None # bool
        #Board of Health Certification Number
        self.health_cert_number = None # str
        #Mobile Phone Number
        self.mobile_phone = None # str
        #Hire Date
        self.date_hired = None # str
        #Home Phone Number
        self.home_phone = None # str
        #Country of Nationality
        self.country_of_nationality = None # str
        #Emergency Contact Name
        self.emergency_contact_name = None # str
        #Board of Health Certification Expiration Date
        self.health_cert_expiration_date = None # str
        #Last Review Date
        self.date_last_review = None # str
        #Employee User Name
        self.user_name = None # str
        #Email Address
        self.email = None # str
        #Employee ID
        self.employee_id = None # int
        
