#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class Tab:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'payment_id': 'int',
            'name_on_card': 'str',
            'card_type': 'str',
            'expiration_year': 'str',
            'card_nickname': 'str',
            'card_id': 'int',
            'expiration_month': 'str',
            'pos_ticket_id': 'int',
            'table_id': 'int',
            'ticket_id': 'int',
            'table_name': 'str',
            'pre_auth_amount': 'float',
            'last_4_digits': 'str'

        }


        #SubtleData Payment ID
        self.payment_id = None # int
        #Name on Credit Card
        self.name_on_card = None # str
        #Credit Card Type
        self.card_type = None # str
        #Expiration Year
        self.expiration_year = None # str
        #Credit Card Nickname
        self.card_nickname = None # str
        #SubtleData Credit Card ID
        self.card_id = None # int
        #Expiration Month
        self.expiration_month = None # str
        #POS System Ticket Identifier
        self.pos_ticket_id = None # int
        #Table ID
        self.table_id = None # int
        #Ticket ID
        self.ticket_id = None # int
        #Table Name
        self.table_name = None # str
        #Pre Auth Amount
        self.pre_auth_amount = None # float
        #Last 4 Digits on Card
        self.last_4_digits = None # str
        
