#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class MenuItem:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'sku': 'str',
            'food_flag': 'bool',
            'alcohol_flag': 'bool',
            'display_name': 'str',
            'name': 'str',
            'merchandise_flag': 'bool',
            'available_for_order': 'bool',
            'price': 'float',
            'description': 'str',
            'UPC': 'str',
            'ModifierTypes': 'list[Modifiertype]',
            'item_images': 'list[ItemImage]',
            'cost': 'float',
            'revenue_center_id': 'int',
            'item_id': 'int',
            'local_pos_id': 'int',
            'out_of_stock_flag': 'bool'

        }


        #Item SKU
        self.sku = None # str
        #Food Flag
        self.food_flag = None # bool
        #Alcohol Flag
        self.alcohol_flag = None # bool
        #Item Display Name
        self.display_name = None # str
        #Item Name
        self.name = None # str
        #Merchandise Flag
        self.merchandise_flag = None # bool
        #Available For Order Flag
        self.available_for_order = None # bool
        #Item Price
        self.price = None # float
        #Item Description
        self.description = None # str
        #Item UPC
        self.UPC = None # str
        self.ModifierTypes = None # list[Modifiertype]
        self.item_images = None # list[ItemImage]
        #Item Cost Basis
        self.cost = None # float
        #Revenue Center ID
        self.revenue_center_id = None # int
        #Item ID
        self.item_id = None # int
        #Item POS ID
        self.local_pos_id = None # int
        #Out of Stock
        self.out_of_stock_flag = None # bool
        
